@@ -15,5 +15,7 @@ except Exception:  # pylint: disable=broad-except  # pragma: no cover
     # Local copy, not installed with setuptools
     __version__ = "unknown"
 
-from scmdata.run import ScmRun, run_append  # noqa: F401, E402
-from scmdata.database import ScmDatabase  # noqa: F401, E402
+from scmdata.run import ScmRun, run_append
+from scmdata.database import ScmDatabase
+
+__all__ = ["ScmRun", "ScmDatabase", "run_append"]
