@@ -3,6 +3,8 @@ NetCDF4 file operations
 
 Reading and writing :class:`ScmRun <scmdata.run.ScmRun>` to disk as binary
 """
+from __future__ import annotations
+
 try:
     import netCDF4 as nc
 
@@ -13,14 +15,19 @@ except ImportError:  # pragma: no cover
 
 from datetime import datetime
 from logging import getLogger
+from typing import TYPE_CHECKING, Any, Iterable, List
 
 import pandas as pd
 import xarray as xr
 
 from . import __version__
+from ._typing import FilePath
 
 logger = getLogger(__name__)
 
+if TYPE_CHECKING:
+    from scmdata.run import BaseScmRun
+
 
 def _var_to_nc(var):
     return var.replace("|", "__").replace(" ", "_")
@@ -45,7 +52,13 @@ def _get_xr_dataset_to_write(run, dimensions, extras):
     return xr_ds
 
 
-def _write_nc(fname, run, dimensions, extras, **kwargs):
+def _write_nc(
+    fname: FilePath,
+    run: BaseScmRun,
+    dimensions: List[str],
+    extras: List[str],
+    **kwargs: Any,
+) -> None:
     """
     Low level function to write the dimensions, variables and metadata to disk
     """
@@ -61,14 +74,14 @@ def _write_nc(fname, run, dimensions, extras, **kwargs):
     xr_ds.to_netcdf(fname, **write_kwargs)
 
 
-def _read_nc(cls, fname):
+def _read_nc(cls: BaseScmRun, fname: FilePath) -> BaseScmRun:
     loaded = xr.load_dataset(fname, use_cftime=True)
     dataframe = loaded.to_dataframe()
 
     dataframe = _reshape_to_scmrun_dataframe(dataframe, loaded)
     run = _convert_to_cls_and_add_metadata(dataframe, loaded, cls)
 
-    return run
+    return run  # type: ignore
 
 
 def _reshape_to_scmrun_dataframe(dataframe, loaded):
@@ -129,7 +142,13 @@ def _update_kwargs_to_match_serialised_variable_names(xr_ds, in_kwargs):
     return _update_kwargs(in_kwargs)
 
 
-def run_to_nc(run, fname, dimensions=("region",), extras=(), **kwargs):
+def run_to_nc(
+    run: BaseScmRun,
+    fname: FilePath,
+    dimensions: Iterable[str] = ("region",),
+    extras: Iterable[str] = (),
+    **kwargs: Any,
+) -> None:
     """
     Write timeseries to disk as a netCDF4 file
 
@@ -139,7 +158,7 @@ def run_to_nc(run, fname, dimensions=("region",), extras=(), **kwargs):
 
     Parameters
     ----------
-    fname : str
+    fname : str | pathlib.Path
         Path to write the file into
 
     dimensions : iterable of str
@@ -172,19 +191,18 @@ def run_to_nc(run, fname, dimensions=("region",), extras=(), **kwargs):
     if not has_netcdf:
         raise ImportError("netcdf4 is not installed. Run 'pip install netcdf4'")
 
-    dimensions = list(dimensions)
-    extras = list(extras)
+    _dimensions = list(dimensions)
 
-    if "time" in dimensions:
-        dimensions.remove("time")
+    if "time" in _dimensions:
+        _dimensions.remove("time")
 
-    if "variable" in dimensions:
-        dimensions.remove("variable")
+    if "variable" in _dimensions:
+        _dimensions.remove("variable")
 
-    _write_nc(fname, run, dimensions, extras, **kwargs)
+    _write_nc(fname, run, _dimensions, list(extras), **kwargs)
 
 
-def nc_to_run(cls, fname):
+def nc_to_run(cls: BaseScmRun, fname: FilePath) -> BaseScmRun:
     """
     Read a netCDF4 file from disk
 
@@ -207,7 +225,7 @@ def nc_to_run(cls, fname):
         raise
 
 
-def inject_nc_methods(cls):
+def inject_nc_methods(cls: type[BaseScmRun]) -> None:
     """
     Add the to/from nc methods to a class
 
